@@ -296,9 +296,7 @@ class Ontology:
 
     @property
     def equivalence_axioms(self):
-        """Return all the equivalence axioms in the `OWLOntology`.
-        
-            NOTE: (checked with protege)
+        """Return all the equivalence class axioms asserted in this `OWLOntology`.
         """
         if not self._equiv_axioms:
             self._equiv_axioms = []
@@ -405,7 +403,7 @@ class Ontology:
         !!! credit "paper"
     
             This refers to the ontology pruning algorithm introduced in the paper: 
-            [Machine Learning-Friendly Biomedical Datasets for Equivalence and Subsumption Ontology Matching (ISWC 2022)](https://link.springer.com/chapter/10.1007/978-3-031-19433-7_33).
+            [*Machine Learning-Friendly Biomedical Datasets for Equivalence and Subsumption Ontology Matching (ISWC 2022)*](https://link.springer.com/chapter/10.1007/978-3-031-19433-7_33).
 
         For each class $c$ to be pruned, subsumption axioms will be created between $c$'s parents and children so as to preserve the
         relevant hierarchy.
@@ -651,13 +649,13 @@ class OntologyReasoner:
         
         !!! note
 
-            Two class expressions C and D are assumed to be disjoint if they meet the followings:
+            Two class expressions $C$ and $D$ are assumed to be disjoint if they meet the followings:
             
-            1. By adding the disjointness axiom of them into the ontology, C and D are **still satisfiable**.
-            2. C and D **do not have a common descendant** (otherwise C and D can be satisfiable but their
+            1. By adding the disjointness axiom of them into the ontology, $C$ and $D$ are **still satisfiable**.
+            2. $C$ and $D$ **do not have a common descendant** (otherwise $C$ and $D$ can be satisfiable but their
             common descendants become the bottom $\bot$.) 
         
-        Note that the special case where C and D are already disjoint is covered by the first check.
+        Note that the special case where $C$ and $D$ are already disjoint is covered by the first check.
         The paper also proposed a practical alternative to decide Assumed Disjointness. 
         See [`check_assumed_disjoint_alternative`][deeponto.onto.OntologyReasoner.check_assumed_disjoint_alternative].
         
@@ -726,7 +724,7 @@ class OntologyReasoner:
         
         !!! note
         
-            Two class expressions C and D are assumed to be disjoint if they
+            Two class expressions $C$ and $D$ are assumed to be disjoint if they
             
             1. **do not** have a **subsumption relationship** between them, 
             2. **do not** have a **common descendant** (in TBox), 
